@@ -126,20 +126,20 @@ CertifyCertificateCommand::CertifyCertificateCommand(QAbstractItemView *v, KeyLi
     d->init();
 }
 
-CertifyCertificateCommand::CertifyCertificateCommand(const Key &key)
+CertifyCertificateCommand::CertifyCertificateCommand(const GpgME::Key &key)
     : Command(key, new Private(this, nullptr))
 {
     d->init();
 }
 
-CertifyCertificateCommand::CertifyCertificateCommand(const UserID &uid)
+CertifyCertificateCommand::CertifyCertificateCommand(const GpgME::UserID &uid)
     : Command(uid.parent(), new Private(this, nullptr))
 {
     std::vector<UserID>(1, uid).swap(d->uids);
     d->init();
 }
 
-CertifyCertificateCommand::CertifyCertificateCommand(const std::vector<UserID> &uids)
+CertifyCertificateCommand::CertifyCertificateCommand(const std::vector<GpgME::UserID> &uids)
     : Command(uids.empty() ? Key() : uids.front().parent(), new Private(this, nullptr))
 {
     d->uids = uids;
@@ -215,11 +215,7 @@ void CertifyCertificateCommand::doStart()
             cmd->setParentWidget(d->parentWidgetOrView());
             cmd->setProtocol(GpgME::OpenPGP);
             loop.connect(cmd, SIGNAL(finished()), SLOT(quit()));
-#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
             QMetaObject::invokeMethod(cmd, &Commands::NewCertificateCommand::start, Qt::QueuedConnection);
-#else
-            QMetaObject::invokeMethod(cmd, "start", Qt::QueuedConnection);
-#endif
             loop.exec();
         } else {
             Q_EMIT(canceled());
